@@ -28,6 +28,8 @@ pub mod error;
 pub mod lockfile;
 mod prelude;
 pub mod presenter;
+mod sarif;
+pub use sarif::SarifLog;
 
 /// Current version of the `cargo-audit` crate
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
